@@ -1,14 +1,17 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-import shopify
+from decimal import Decimal
+
 import pyactiveresource
+import shopify
 
 from trytond.i18n import gettext
 from trytond.model import ModelSQL, ModelView, fields
 from trytond.model.exceptions import AccessError
-from trytond.pool import PoolMeta, Pool
-from trytond.pyson import Eval, If, Bool
+from trytond.pool import Pool, PoolMeta
+from trytond.pyson import Bool, Eval, If
 from trytond.tools import grouped_slice, slugify
+from trytond.transaction import Transaction
 
 from .common import IdentifiersMixin, IdentifiersUpdateMixin
 
@@ -72,7 +75,7 @@ class Template(IdentifiersMixin, metaclass=PoolMeta):
             'readonly': Bool(Eval('shopify_identifiers', [-1])),
             'invisible': ~Eval('salable', False),
             },
-        depends=['default_uom_category', 'shopify_identifiers', 'salable'])
+        depends={'default_uom_category'})
 
     @classmethod
     def __setup__(cls):
@@ -86,7 +89,6 @@ class Template(IdentifiersMixin, metaclass=PoolMeta):
             ('category', 'in', [Eval(c, -1) for c in categories]),
             ('digits', '=', 0),
             ]
-        cls.shopify_uom.depends.extend(categories)
 
     @classmethod
     def _shopify_uom_categories(cls):
@@ -205,7 +207,10 @@ class Product(IdentifiersMixin, metaclass=PoolMeta):
         variant.sku = self.shopify_sku
         price = self.shopify_price(
             price, tax, taxes_included=shop_taxes_included)
-        variant.price = str(price) if price is not None else None
+        if price is not None:
+            variant.price = str(price.quantize(Decimal('.00')))
+        else:
+            variant.price = None
         variant.taxable = bool(tax)
         for identifier in self.identifiers:
             if identifier.type == 'ean':
@@ -340,7 +345,8 @@ class ShopifyInventoryItem_Customs(metaclass=PoolMeta):
         Date = pool.get('ir.date')
         inventory_item = super().get_shopify(shop)
         if inventory_item:
-            today = Date.today()
+            with Transaction().set_context(company=shop.company.id):
+                today = Date.today()
             inventory_item.country_code_of_origin = (
                 self.product.country_of_origin.code
                 if self.product.country_of_origin else None)
@@ -464,8 +470,7 @@ class AttributeSet(IdentifiersUpdateMixin, metaclass=PoolMeta):
             If(Eval('shopify_option3'),
                 ('id', '!=', Eval('shopify_option3')),
                 ()),
-            ],
-        depends=['attributes', 'shopify_option2', 'shopify_option3'])
+            ])
     shopify_option2 = fields.Many2One(
         'product.attribute', "Option 2",
         domain=[
@@ -479,8 +484,7 @@ class AttributeSet(IdentifiersUpdateMixin, metaclass=PoolMeta):
             ],
         states={
             'invisible': ~Eval('shopify_option1'),
-            },
-        depends=['attributes', 'shopify_option1', 'shopify_option3'])
+            })
     shopify_option3 = fields.Many2One(
         'product.attribute', "Option 3",
         domain=[
@@ -494,8 +498,7 @@ class AttributeSet(IdentifiersUpdateMixin, metaclass=PoolMeta):
             ],
         states={
             'invisible': ~Eval('shopify_option2'),
-            },
-        depends=['attributes', 'shopify_option1', 'shopify_option2'])
+            })
 
     @classmethod
     def __setup__(cls):
